/**
 * Executes the middleware stack in sequence
 * @param params - The loader context
 * @param middlewareOptions - The middleware options
 * @param middlewareStack - The middleware stack
 * @returns The middleware options
 */
async function loaderWithMiddleware(params, middlewareOptions, middlewareStack) {
    const { logger } = params.context;
    logger.debug('middlewares [%j]', middlewareStack);
    const loaderData = middlewareOptions ? middlewareOptions : {};
    const executeMiddlewares = async (index) => {
        if (index < middlewareStack.length) {
            const middleware = middlewareStack[index];
            const start = process.hrtime(); // Get start time
            logger.debug(`[[Middleware ${middleware.name}]] starts to run`);
            await middleware.func(params, loaderData, async () => await executeMiddlewares(index + 1));
            const end = process.hrtime(start); // Get end time
            const elapsedTime = (end[0] * 1e9 + end[1]) / 1e6; // Convert to milliseconds
            logger.debug(`[[Middleware ${middleware.name}]] took ${elapsedTime} ms`);
        }
    };
    await executeMiddlewares(0); // Start middleware execution from the first one
    return loaderData;
}export{loaderWithMiddleware};